---
title: "Getting Started"
description: Getting started guide for Kodit.
weight: 1
next: /kodit/getting-started/installation
---

The following sections show you how to get started with Kodit:

<!--more-->

{{< default-section-cards-list >}}
